import PropTypes from 'prop-types';
import React from 'react';
import { YouTubePlayer, Options } from 'youtube-player/dist/types';

declare type YouTubeProps = {
    videoId?: string;
    id?: string;
    className?: string;
    containerClassName?: string;
    containerStyle?: React.CSSProperties;
    title?: string;
    loading?: 'lazy' | 'eager' | 'auto';
    opts?: Options;
    onReady?: (event: CustomEvent) => void;
    onError?: (event: CustomEvent) => void;
    onPlay?: (event: CustomEvent) => void;
    onPause?: (event: CustomEvent) => void;
    onEnd?: (event: CustomEvent) => void;
    onStateChange?: (event: CustomEvent) => void;
    onPlaybackRateChange?: (event: CustomEvent) => void;
    onPlaybackQualityChange?: (event: CustomEvent) => void;
} & typeof defaultProps;
declare const defaultProps: {
    videoId: string;
    id: string;
    className: string;
    loading: string;
    opts: {};
    containerClassName: string;
    containerStyle: {};
    onReady: () => void;
    onError: () => void;
    onPlay: () => void;
    onPause: () => void;
    onEnd: () => void;
    onStateChange: () => void;
    onPlaybackRateChange: () => void;
    onPlaybackQualityChange: () => void;
    title: string;
};
declare class YouTube extends React.Component<YouTubeProps> {
    static propTypes: {
        videoId: PropTypes.Requireable<string>;
        id: PropTypes.Requireable<string>;
        className: PropTypes.Requireable<string>;
        containerClassName: PropTypes.Requireable<string>;
        containerStyle: PropTypes.Requireable<object>;
        title: PropTypes.Requireable<string>;
        loading: PropTypes.Requireable<string>;
        opts: PropTypes.Requireable<{
            [x: string]: any;
        }>;
        onReady: PropTypes.Requireable<(...args: any[]) => any>;
        onError: PropTypes.Requireable<(...args: any[]) => any>;
        onPlay: PropTypes.Requireable<(...args: any[]) => any>;
        onPause: PropTypes.Requireable<(...args: any[]) => any>;
        onEnd: PropTypes.Requireable<(...args: any[]) => any>;
        onStateChange: PropTypes.Requireable<(...args: any[]) => any>;
        onPlaybackRateChange: PropTypes.Requireable<(...args: any[]) => any>;
        onPlaybackQualityChange: PropTypes.Requireable<(...args: any[]) => any>;
    };
    static defaultProps: {
        videoId: string;
        id: string;
        className: string;
        loading: string;
        opts: {};
        containerClassName: string;
        containerStyle: {};
        onReady: () => void;
        onError: () => void;
        onPlay: () => void;
        onPause: () => void;
        onEnd: () => void;
        onStateChange: () => void;
        onPlaybackRateChange: () => void;
        onPlaybackQualityChange: () => void;
        title: string;
    };
    /**
     * Expose PlayerState constants for convenience. These constants can also be
     * accessed through the global YT object after the YouTube IFrame API is instantiated.
     * https://developers.google.com/youtube/iframe_api_reference#onStateChange
     */
    static PlayerState: {
        UNSTARTED: number;
        ENDED: number;
        PLAYING: number;
        PAUSED: number;
        BUFFERING: number;
        CUED: number;
    };
    container: HTMLDivElement | null;
    internalPlayer: YouTubePlayer | null;
    constructor(props: any);
    componentDidMount(): void;
    componentDidUpdate(prevProps: YouTubeProps): void;
    componentWillUnmount(): void;
    /**
     * https://developers.google.com/youtube/iframe_api_reference#onReady
     */
    onPlayerReady: (event: CustomEvent) => void;
    /**
     * https://developers.google.com/youtube/iframe_api_reference#onError
     */
    onPlayerError: (event: CustomEvent) => void;
    /**
     * https://developers.google.com/youtube/iframe_api_reference#onStateChange
     */
    onPlayerStateChange: (event: CustomEvent) => void;
    /**
     * https://developers.google.com/youtube/iframe_api_reference#onPlaybackRateChange
     */
    onPlayerPlaybackRateChange: (event: CustomEvent) => void;
    /**
     * https://developers.google.com/youtube/iframe_api_reference#onPlaybackQualityChange
     */
    onPlayerPlaybackQualityChange: (event: CustomEvent) => void;
    /**
     * Initialize the YouTube Player API on the container and attach event handlers
     */
    createPlayer: () => void;
    /**
     * Shorthand for destroying and then re-creating the YouTube Player
     */
    resetPlayer: () => Promise<void> | undefined;
    /**
     * Method to update the id and class of the YouTube Player iframe.
     * React should update this automatically but since the YouTube Player API
     * replaced the DIV that is mounted by React we need to do this manually.
     */
    updatePlayer: () => void;
    /**
     *  Method to return the internalPlayer object.
     */
    getInternalPlayer: () => YouTubePlayer | null;
    /**
     * Call YouTube Player API methods to update the currently playing video.
     * Depending on the `opts.playerVars.autoplay` this function uses one of two
     * YouTube Player API methods to update the video.
     */
    updateVideo: () => void;
    refContainer: (container: HTMLDivElement) => void;
    render(): JSX.Element;
}

export { YouTube as default };
